xz: General-purpose data compression software
=============================================

Description
-----------

XZ Utils is free general-purpose data compression software with a high
compression ratio.

License
-------

Some parts public domain, other parts GNU LGPLv2.1, GNU GPLv2, or GNU
GPLv3.


Upstream Contact
----------------

http://tukaani.org/xz/

Dependencies
------------
